Virga
=====

From `Wikipedia <https://en.wikipedia.org/wiki/Virga>`_: *"In meteorology, Virga is an observable streak or shaft of
precipitation falling from a cloud that evaporates or sublimates before reaching the ground."*

This piece of software is not about a weather phenomenon. Virga is a tool for analysing your Cloud infrastructure
before the rain catastrophically reaches the ground.

For the documentation see `the code repository <https://github.com/gurdulu/virga>`_.
